Package: rms
Version: 5.1-1
Date: 2017-05-01
Title: Regression Modeling Strategies
Author: Frank E Harrell Jr <f.harrell@vanderbilt.edu>
Maintainer: Frank E Harrell Jr <f.harrell@vanderbilt.edu>
Depends: Hmisc (>= 4.0-2), survival (>= 2.40-1), lattice, ggplot2 (>=
        2.2), SparseM
Imports: methods, quantreg, rpart, nlme (>= 3.1-123), polspline,
        multcomp, htmlTable, htmltools
Suggests: boot, tcltk, plotly (>= 4.5.6)
Description: Regression modeling, testing, estimation, validation,
	graphics, prediction, and typesetting by storing enhanced model design
	attributes in the fit.  'rms' is a collection of functions that
	assist with and streamline modeling.  It also contains functions for
	binary and ordinal logistic regression models, ordinal models for
  continuous Y with a variety of distribution families, and the Buckley-James
	multiple regression model for right-censored responses, and implements
	penalized maximum likelihood estimation for logistic and ordinary
	linear models.  'rms' works with almost any regression model, but it
	was especially written to work with binary or ordinal regression
	models, Cox regression, accelerated failure time models,
	ordinary linear models,	the Buckley-James model, generalized least
	squares for serially or spatially correlated observations, generalized
	linear models, and quantile regression.
License: GPL (>= 2)
URL: http://biostat.mc.vanderbilt.edu/rms
LazyLoad: yes
NeedsCompilation: yes
Packaged: 2017-05-03 14:03:12 UTC; harrelfe
Repository: CRAN
Date/Publication: 2017-05-03 16:41:23 UTC
Built: R 3.3.2; x86_64-w64-mingw32; 2018-02-14 14:11:19 UTC; windows
Archs: x64
