export(annotateAnova,asis,bj,bjplot,bootBCa,bootcov,bootplot,bplot,calibrate,cph,catg,combineRelatedPredictors,confplot,contrast,coxphFit,cph,cr.setup,datadist,dxy.cens,effective.df,ExProb,fastbw,formatNP,gendata,gIndex,Glm,Gls,groupkm,Hazard,hazard.ratio.plot,histdensity,"%ia%",ie.setup,interactions.containing,legend.nomabbrev,lm.pfit,lrm,lrm.fit,lrtest,lsp,matinv,matrx,Newlabels,Newlevels,nomogram,npsurv,ols,ols.influence,oos.loglik,orm,orm.fit,pantext,Penalty.matrix,Penalty.setup,pentrace,perimeter,perlcode,plotmathAnova,plotp,plot.lrm.partial,plot.xmean.ordinaly,pol,pphsm,predab.resample,Predict,psm,rcs,related.predictors,reListclean,robcov,Rq,sascode,scored,sensuc,setPb,show.influence,specs,strat,survreg.auxinfo,survdiffplot,survest,Survival,survplot,survplotp,univarLR,validate,val.prob,val.probg,val.surv,vif,which.influence)

useDynLib(rms, .registration=TRUE, .fixes="F_")


import(Hmisc)
importFrom(survival, Surv, is.Surv, survConcordance.fit, coxph.fit, coxph.control, survfit, survfitcoxph.fit, survreg.fit, survreg.control, survpenal.fit, survfitKM, survreg.distributions, agreg.fit, agexact.fit, attrassign, untangle.specials)
importFrom(stats, nobs)
#importFrom(SparseM, solve, t, as.matrix)
import(SparseM)

import(ggplot2)
import(lattice)
#import(gridExtra)  # DOES NOT WORK UNLESS IN Depends IN DESCRIPTION
#importFrom(gridExtra, arrangeGrob)
importFrom(quantreg, rq.wfit, rq.fit, summary.rq)
import(nlme)
importFrom(rpart, rpart, rpart.control, prune)
importFrom(polspline, hare, phare)
import(multcomp)
# importFrom(multcomp, confint.glht, glht)  FAILS confint.glht not exported by namespace:multcomp
importFrom(htmlTable, htmlTable, txtRound)
importFrom(htmltools, HTML)

importFrom(grDevices, gray, grey, rgb)
importFrom(graphics, abline, axis, boxplot, hist, legend,
           lines, locator, mtext, par, plot, plot.new,
           points, segments, strwidth, symbols, text,
           title, grconvertX, grconvertY)
importFrom(methods, existsFunction, getFunction, new)
importFrom(stats, .getXlevels, AIC, approx, as.formula,
           asOneSidedFormula, coef, confint, contrasts, cor,
           dcauchy, delete.response, density, deviance,
           dnorm, family, fitted, formula, gaussian,
           glm.control, glm.fit, is.empty.model, lm, lm.fit,
           lm.influence, lm.wfit, logLik, lowess, lsfit,
           make.link, median, model.extract, model.frame,
           model.offset, model.weights, na.omit, naresid,
           nlminb, optim, pcauchy, pchisq, pf, plogis,
           pnorm, predict, pt, qcauchy, qchisq, qlogis,
           qnorm, qqline, qqnorm, qt, quantile,
           reformulate, reshape, resid, residuals, runif,
           supsmu, terms, uniroot, update, var, vcov)
importFrom(utils, capture.output, de, getS3method, getFromNamespace)


S3method(AIC, rms)
S3method(anova, rms)

S3method(calibrate, cph)
S3method(calibrate, default)
S3method(calibrate, psm)

S3method(contrast, rms)

S3method(ExProb, orm)
         
S3method(Function, cph)
S3method(Function, rms)

S3method(Hazard, psm)

S3method(html, anova.rms)
S3method(html, naprint.delete)
S3method(html, summary.rms)
S3method(html, validate)

S3method(latex, anova.rms)
S3method(latex, bj)
S3method(latex, cph)
S3method(latex, Glm)
S3method(latex, Gls)
S3method(latex, lrm)
S3method(latex, naprint.delete)
S3method(latex, ols)
S3method(latex, orm)
S3method(latex, pphsm)
S3method(latex, psm)
S3method(latex, Rq)
S3method(latex, summary.rms)
S3method(latex, validate)

S3method(lines, residuals.psm.censored.normalized)

S3method(logLik, Gls)
S3method(logLik, ols)
S3method(logLik, rms)

S3method(Mean,  cph)
S3method(Mean,  lrm)
S3method(Mean,  orm)
S3method(Mean,  psm)

S3method(Newlabels, rms)
S3method(Newlevels, rms)

S3method(nobs, rms)

S3method(plot, anova.rms)
S3method(plot, calibrate)
S3method(plot, calibrate.default)
S3method(plot, ExProb)
S3method(plot, gIndex)
S3method(plot, lrm.partial)
S3method(plot, nomogram)
S3method(plot, pentrace)
S3method(plot, Predict)
S3method(plot, sensuc)
S3method(plot, summary.rms)
S3method(plot, validate.rpart)
S3method(plot, val.prob)
S3method(plot, val.surv)
S3method(plot, val.survh)
S3method(plot, xmean.ordinaly)

S3method(plotp, Predict)

S3method(ggplot, Predict)

S3method(predict, bj)
S3method(predict, cph)
S3method(predict, Glm)
S3method(predict, Gls)
S3method(predict, lrm)
S3method(predict, ols)
S3method(predict, orm)
S3method(predict, psm)
S3method(predict, Rq)

S3method(print, anova.rms)
S3method(print, bj)
S3method(print, calibrate)
S3method(print, contrast.rms)
S3method(print, cph)
S3method(print, datadist)
S3method(print, fastbw)
S3method(print, gIndex)
S3method(print, Glm)
S3method(print, Gls)
S3method(print, lrm)
S3method(print, lrtest)
S3method(print, nomogram)
S3method(print, ols)
S3method(print, orm)
S3method(print, pentrace)
S3method(print, pphsm)
S3method(print, Predict)
S3method(print, psm)
S3method(print, Rq)
S3method(print, specs.rms)
S3method(print, summary.rms)
S3method(print, summary.survreg2)
S3method(print, survest.psm)
S3method(print, validate)
S3method(print, validate.rpart)
S3method(print, val.prob)
S3method(print, val.survh)

S3method(Quantile, cph)
S3method(Quantile, orm)
S3method(Quantile, psm)

S3method(rbind, Predict)

S3method(residuals, bj)
S3method(residuals, cph)
S3method(residuals, lrm)
S3method(residuals, ols)
S3method(residuals, orm)
S3method(residuals, psm)

S3method(specs, rms)
S3method(summary, rms)

S3method(survest, cph)
S3method(survest, psm)

S3method(survfit, cph)

S3method(survplot, residuals.psm.censored.normalized)
S3method(survplot, rms)
S3method(survplot, npsurv)

S3method(survplotp, npsurv)

S3method(Survival, cph)
S3method(Survival, psm)

S3method(validate, bj)
S3method(validate, cph)
S3method(validate, lrm)
S3method(validate, ols)
S3method(validate, orm)
S3method(validate, psm)
S3method(validate, rpart)
S3method(validate, Rq)

S3method(vcov, cph)
S3method(vcov, Glm)
S3method(vcov, Gls)
S3method(vcov, lrm)
S3method(vcov, ols)
S3method(vcov, orm)
S3method(vcov, pphsm)
S3method(vcov, psm)
S3method(vcov, rms)

S3method("[", rms)
